@@ -1,4 +1,4 @@
-/* Stereograph 0.12, 16/02/2000;
+/* Stereograph 0.13, 31/03/2000;
  * renderer, stereographer's engine;
  * Copyright (c) 2000 by Fabian Januszewski <fabian.linux@januszewski.de>
  *
@@ -16,6 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
+
 #define _GNU_SOURCE
 
 #include <stdio.h>
@@ -109,18 +110,16 @@ int RenderLine(int *base_data, int *texture_data, int *stereo_data)
 	
 	FillMapsLeftToRight(base_data);
 
-	InsertTex(Renderer.startx, texture_data, stereo_data);
-
 	if(Param.AA - 1)
 	{
    		if(Param.Zoom)
-			return ZoomAAScan(stereo_data);
+			return ZoomAAScan(stereo_data, texture_data);
 		else
-			return AAScan(stereo_data);
+			return AAScan(stereo_data, texture_data);
 	} else if(Param.Zoom)
-		return ZoomScan(stereo_data);
+		return ZoomScan(stereo_data, texture_data);
 	else
-		return NormalScan(stereo_data);
+		return NormalScan(stereo_data, texture_data);
 }
 
 
@@ -179,27 +178,15 @@ float GetChange(int x, int *base_data)
 }
 
 
-/* insert the texture at (x) */
-int InsertTex(int x, int *texture_data, int *stereo_data)
-{
-	int z;
-	int a;
-	if(Param.Zoom != 0)
-	   	for(z = 0; z < Texture.Width; z++)
-			for (a = 0; a <= Param.Zoom; a++)
-				stereo_data[((x + z) * Renderer.nzoom) + a] = texture_data[z];
-	else
-		memcpy(stereo_data + x, texture_data, Texture.Width * sizeof(int));
-	return 0;
-}
-
-
 /* reference renderer without any special effects */
-int NormalScan(int *stereo_data)
+int NormalScan(int *stereo_data, int *texture_data)
 {
 	float z;
 	int scanx;
 
+	/* insert the texture at x */
+	memcpy(stereo_data + Renderer.startx, texture_data, Texture.Width * sizeof(int));
+
 	/* we've to scan into two directions, beginning @ startx */
 	for (scanx = Renderer.startx; scanx < (Renderer.startx + Texture.Width); scanx++)
 	{
@@ -227,17 +214,16 @@ int NormalScan(int *stereo_data)
 
 
 /* First and most effective of all special: anti-aliasing */
-int AAScan(int *stereo_data)
+int AAScan(int *stereo_data, int *texture_data)
 {
 	int scanx,a;
 	float z;
 	int r, g, b;
 
-        /* move to inserttex etc. */
-	for (scanx = 0; scanx < Stereo.Width; scanx++)
-		for (a = 0; a < Renderer.naa; a++)
-			Renderer.scanline[(scanx * Renderer.nfactor) + a] = stereo_data[scanx];
-
+        /* insert the texture without any special fx */
+	for (scanx = 0; scanx < Texture.Width; scanx++)
+		for (a = 0; a < Renderer.nfactor; a++)
+			Renderer.scanline[((scanx + Renderer.startx) * Renderer.nfactor) + a] = texture_data[scanx];
 
 	/* scanning... */
 	for (scanx = Renderer.startx; scanx < (Renderer.startx + Texture.Width); scanx++)
@@ -286,11 +272,16 @@ int AAScan(int *stereo_data)
 
 
 /* Second effect: zoom */
-int ZoomScan(int *stereo_data)
+int ZoomScan(int *stereo_data, int *texture_data)
 {
 	int scanx, a;
 	float z;
 
+        /* insert the texture without any special fx */
+	for (scanx = 0; scanx < Texture.Width; scanx++)
+		for (a = 0; a < Renderer.nfactor; a++)
+			stereo_data[((scanx + Renderer.startx) * Renderer.nfactor) + a] = texture_data[scanx];
+
         /* already scanning, nothing to prepare */
 	for (scanx = Renderer.startx; scanx < (Renderer.startx + Texture.Width); scanx++)
 	{
@@ -328,17 +319,18 @@ int ZoomScan(int *stereo_data)
 
 
 /* ZOOM'N'AA */
-/* Final effects: all two above together */
-int ZoomAAScan(int *stereo_data)
+/* Final effects: fx pair in cooperation */
+int ZoomAAScan(int *stereo_data, int *texture_data)
 {
 	int scanx, a;
 	float z;
 	int r, g, b;
 
-	/* as anti-aliasing implementation above */
-	for (scanx = 0; scanx < Stereo.Width; scanx++)
-		for (a = 0; a < Renderer.naa; a++)
-			Renderer.scanline[(scanx * Renderer.naa) + a] = stereo_data[scanx];
+        /* insert the texture without any special fx */
+	/* the same as anti-aliasing implementation above */
+	for (scanx = 0; scanx < Texture.Width; scanx++)
+		for (a = 0; a < Renderer.nfactor; a++)
+			Renderer.scanline[((scanx + Renderer.startx) * Renderer.nfactor) + a] = texture_data[scanx];
 
 	/* scanning */
 	for (scanx = Renderer.startx; scanx < (Renderer.startx + Texture.Width); scanx++)
